@@ -24,7 +24,4 @@
 /* Output the parsing tables and the parser code to FTABLE.  */
 void output (void);
 
-/* Where our data files are installed.  */
-char const *pkgdatadir (void);
-
 #endif /* !OUTPUT_H_ */
